@@ -4,11 +4,11 @@ Woopra template tags and filters.
 
 from __future__ import absolute_import
 
+import json
 import re
 
 from django.conf import settings
 from django.template import Library, Node, TemplateSyntaxError
-from django.utils import simplejson
 
 from analytical.utils import get_identity, get_user_from_context, \
         is_internal_ip, disable_html, get_required_setting
@@ -57,8 +57,8 @@ class WoopraNode(Node):
         visitor = self._get_visitor(context)
 
         html = TRACKING_CODE % {
-            'settings': simplejson.dumps(settings),
-            'visitor': simplejson.dumps(visitor),
+            'settings': json.dumps(settings, sort_keys=True),
+            'visitor': json.dumps(visitor, sort_keys=True),
         }
         if is_internal_ip(context, 'WOOPRA'):
             html = disable_html(html, 'Woopra')
@@ -80,7 +80,7 @@ class WoopraNode(Node):
                     vars[var[7:]] = val
         if 'name' not in vars and 'email' not in vars:
             user = get_user_from_context(context)
-            if user is not None:
+            if user is not None and user.is_authenticated():
                 vars['name'] = get_identity(context, 'woopra',
                         self._identify, user)
                 if user.email:
